"""Top-level package for SSH2 Key Parsing."""
from .ssh2_parse_key import Ssh2Key as _Ssh2Key

Ssh2Key = _Ssh2Key

__author__ = "Nigel Metheringham"
__email__ = "nigelm@cpan.org"
__version__ = "0.2.3"
